==> config_widget-0.0.6.tar.gz: bin/analyze/config_widget_package.dart <==
import 'dart:io';
import 'package:path/path.dart' as path;
import 'package:pubspec_parse/pubspec_parse.dart';

bool isTest = false;
Future<List<String>> containConfigWidgetPackagePath(String rootPath) async {
  if (isTest) {
    return ['/Users/dansun/Documents/GitHub/config_widget/example/lib/example/example8.dart'];
  }
  final String pubspecYaml = File('$rootPath/pubspec.yaml').readAsStringSync();

  Pubspec pubspec = Pubspec.parse(pubspecYaml);

  final List<String> packages = [];

  if (isContainConfig(pubspec)) {
    packages.add(rootPath);
  }
  pubspec.dependencies.values.forEach((element) {
    if (element is PathDependency) {
      String packagePath = path.join(rootPath, element.path);
      final Pubspec pubspecYaml = Pubspec.parse(File('$packagePath/pubspec.yaml').readAsStringSync());
      bool isContain = isContainConfig(pubspecYaml);
      if (isContain) {
        packages.add(packagePath);
      }
    }
  });

  return await searchPaths(packages);
}

bool isContainConfig(Pubspec pubspecYaml) {
  return pubspecYaml.dependencies.keys.any((element) => element.contains('config_widget'));
}

Future<List<String>> searchPaths(List<String> packagePaths) async {
  List<String> searchPaths = packagePaths.map((element) {
    return path.join(
      element,
      "lib",
    );
  }).toList();

  List<String> resultList = [];
  for (String element in searchPaths) {
    Directory directory = Directory(element);
    await directory.list(recursive: true).forEach((entry) async {
      if (entry is File) {
        resultList.add(entry.path);
      }
    });
  }

  return resultList;
}

==> config_widget-0.0.7.tar.gz: bin/analyze/config_widget_package.dart <==
import 'dart:io';
import 'package:path/path.dart' as path;
import 'package:pubspec_parse/pubspec_parse.dart';

bool isTest = false;
Future<List<String>> containConfigWidgetPackagePath(String rootPath) async {
  if (isTest) {
    return ['/Users/dansun/Documents/GitHub/config_widget/example/lib/example/example8.dart'];
  }
  final String pubspecYaml = File('$rootPath/pubspec.yaml').readAsStringSync();

  Pubspec pubspec = Pubspec.parse(pubspecYaml);

  final List<String> packages = [];

  if (isContainConfig(pubspec)) {
    packages.add(rootPath);
  }
  pubspec.dependencies.values.forEach((element) {
    if (element is PathDependency) {
      String packagePath;
      if (element.path.contains('../')) {
        packagePath = path.join(rootPath.replaceAll('/${path.basename(rootPath)}', ''), element.path.replaceAll('../', ''));
      } else {
        packagePath = path.join(rootPath, element.path);
      }

      if (packagePath.contains('package')) {
        final Pubspec pubspecYaml = Pubspec.parse(File('$packagePath/pubspec.yaml').readAsStringSync());
        bool isContain = isContainConfig(pubspecYaml);
        if (isContain) {
          packages.add(packagePath);
        }
      }
    }
  });

  return await searchPaths(packages);
}

bool isContainConfig(Pubspec pubspecYaml) {
  return pubspecYaml.dependencies.keys.any((element) => element.contains('config_widget'));
}

Future<List<String>> searchPaths(List<String> packagePaths) async {
  List<String> searchPaths = packagePaths.map((element) {
    return path.join(
      element,
      "lib",
    );
  }).toList();

  List<String> resultList = [];
  for (String element in searchPaths) {
    Directory directory = Directory(element);
    await directory.list(recursive: true).forEach((entry) async {
      if (entry is File) {
        resultList.add(entry.path);
      }
    });
  }

  return resultList;
}
